@@ -40,7 +40,8 @@ except ImportError:
     import pickle
     print "NOTE: Importing cPickle failed. Falling back to a very slow implementation."
 
-__cache_version__ = "123"
+# __cache_version__ = "123"
+__cache_version__ = "124" # changes the __depends structure
 
 class Cache:
     """
@@ -48,17 +49,21 @@ class Cache:
     """
     def __init__(self, cooker):
 
+
         self.cachedir = bb.data.getVar("CACHE", cooker.configuration.data, True)
-        self.cachefile = os.path.join(self.cachedir,"bb_cache.dat")
         self.clean = {}
         self.depends_cache = {}
         self.data = None
         self.data_fn = None
 
         if self.cachedir in [None, '']:
+            self.has_cache = False
             if cooker.cb is not None:
                 print "NOTE: Not using a cache. Set CACHE = <directory> to enable."
         else:
+            self.has_cache = True
+            self.cachefile = os.path.join(self.cachedir,"bb_cache.dat")
+            
             if cooker.cb is not None:
                 print "NOTE: Using cache in '%s'" % self.cachedir
             try:
@@ -66,7 +71,7 @@ class Cache:
             except OSError:
                 bb.mkdirhier( self.cachedir )
 
-        if (self.mtime(self.cachefile)):
+        if self.has_cache and (self.mtime(self.cachefile)):
             try:
                 p = pickle.Unpickler( file(self.cachefile,"rb"))
                 self.depends_cache, version_data = p.load()
@@ -153,7 +158,7 @@ class Cache:
         Fast version, no timestamps checked.
         """
         # Is cache enabled?
-        if self.cachedir in [None, '']:
+        if not self.has_cache:
             return False
         if fn in self.clean:
             return True
@@ -165,7 +170,7 @@ class Cache:
         Make thorough (slower) checks including timestamps.
         """
         # Is cache enabled?
-        if self.cachedir in [None, '']:
+        if not self.has_cache:
             return False
 
         # Check file still exists
@@ -188,16 +193,12 @@ class Cache:
 
         # Check dependencies are still valid
         depends = self.getVar("__depends", fn, True)
-        if depends:
-            deps = depends.split(" ")
-            for dep in deps:
-                (f,old_mtime_s) = dep.split("@")
-                old_mtime = int(old_mtime_s)
-                new_mtime = bb.parse.cached_mtime(f)
-                if (new_mtime > old_mtime):
-                    bb.debug(2, "Cache: %s's dependency %s changed" % (fn, f))
-                    self.remove(fn)
-                    return False
+        for f,old_mtime in depends:
+            new_mtime = bb.parse.cached_mtime(f)
+            if (new_mtime > old_mtime):
+                bb.debug(2, "Cache: %s's dependency %s changed" % (fn, f))
+                self.remove(fn)
+                return False
 
         bb.debug(2, "Depends Cache: %s is clean" % fn)
         if not fn in self.clean:
@@ -231,6 +232,9 @@ class Cache:
         Called from the parser when complete (or exitting)
         """
 
+        if not self.has_cache:
+            return
+
         version_data = {}
         version_data['CACHE_VER'] = __cache_version__
         version_data['BITBAKE_VER'] = bb.__version__
@@ -267,7 +271,8 @@ class Cache:
         #data.setVar('TOPDIR', topdir, cfg)
         # go there
         oldpath = os.path.abspath(os.getcwd())
-        os.chdir(topdir)
+        if self.mtime(topdir):
+            os.chdir(topdir)
         bb_data = data.init_db(cooker.configuration.data)
         try:
             parse.handle(bbfile, bb_data) # read .bb data
