@@ -133,21 +133,9 @@ class Cvs(Fetch):
                 bb.debug(1, "%s already exists, skipping cvs checkout." % tarfn)
                 continue
 
-            pn = data.getVar('PN', d, 1)
-            cvs_tarball_stash = None
-            if pn:
-                cvs_tarball_stash = data.getVar('CVS_TARBALL_STASH_%s' % pn, d, 1)
-            if cvs_tarball_stash == None:
-                cvs_tarball_stash = data.getVar('CVS_TARBALL_STASH', d, 1)
-            if cvs_tarball_stash:
-                fetchcmd = data.getVar("FETCHCOMMAND_wget", d, 1)
-                uri = cvs_tarball_stash + tarfn
-                bb.note("fetch " + uri)
-                fetchcmd = fetchcmd.replace("${URI}", uri)
-                ret = os.system(fetchcmd)
-                if ret == 0:
-                    bb.note("Fetched %s from tarball stash, skipping checkout" % tarfn)
-                    continue
+            # try to use the tarball stash
+            if Fetch.try_mirror(d, tarfn):
+                continue
 
             if date:
                 options.append("-D %s" % date)
@@ -194,7 +182,7 @@ class Cvs(Fetch):
                 bb.debug(1, "Running %s" % cvscmd)
                 myret = os.system(cvscmd)
 
-            if myret != 0:
+            if myret != 0 or not os.access(moddir, os.R_OK):
                 try:
                     os.rmdir(moddir)
                 except OSError:
